@@ -172,7 +172,7 @@ class CVE(BaseModel):
         super().__init__(**kwargs)
         self.year = int(self.identifier.split("-")[1])
 
-    @validator("identifier")
+    @validator("id")
     def check_type(cls, v):
         assert v.startswith("CVE-"), f"{v} does not start with CVE-"
         assert v.count("-") == 2
